searchData={"items":[{"type":"module","title":"Hyperliquid","doc":"Documentation for `Hyperliquid`.","ref":"Hyperliquid.html"},{"type":"module","title":"Hyperliquid.Api","doc":"A base API macro for interacting with the Hyperliquid API.\r\n\r\nThis module provides a macro that sets up common functionality for API interactions,\r\nincluding signing requests, handling different types of actions, and processing responses.\r\n\r\nWhen used, it imports necessary modules, sets up aliases, and defines several helper functions\r\nfor making API calls.","ref":"Hyperliquid.Api.html"},{"type":"module","title":"Usage - Hyperliquid.Api","doc":"Use this module in other API-specific modules like this:\r\n\r\n    use Hyperliquid.Api, context: \"evm\"","ref":"Hyperliquid.Api.html#module-usage"},{"type":"module","title":"Configuration - Hyperliquid.Api","doc":"This module relies on the following application environment variables:\r\n\r\n- `:http_url` - The base URL for API requests\r\n- `:is_mainnet` - Boolean indicating whether to use mainnet or testnet\r\n- `:private_key` - The private key used for signing requests","ref":"Hyperliquid.Api.html#module-configuration"},{"type":"function","title":"Hyperliquid.Api.handle_response/1","doc":"","ref":"Hyperliquid.Api.html#handle_response/1"},{"type":"module","title":"Hyperliquid.Api.Exchange","doc":"Module for interacting with the Hyperliquid Exchange API endpoints.\r\n\r\nThis module provides functions to perform various operations on the Hyperliquid exchange,\r\nincluding placing and canceling orders, modifying orders, updating leverage, transferring\r\nfunds, and managing sub-accounts.\r\n\r\nIt uses the `Hyperliquid.Api` macro to set up the basic API interaction functionality.","ref":"Hyperliquid.Api.Exchange.html"},{"type":"module","title":"Functions - Hyperliquid.Api.Exchange","doc":"","ref":"Hyperliquid.Api.Exchange.html#module-functions"},{"type":"module","title":"Order Management - Hyperliquid.Api.Exchange","doc":"- `place_order/1`, `place_order/2`, `place_order/3` - Place one or multiple orders\r\n- `cancel_orders/1`, `cancel_orders/2` - Cancel multiple orders\r\n- `cancel_order/2`, `cancel_order/3` - Cancel a single order\r\n- `cancel_order_by_cloid/2`, `cancel_order_by_cloid/3` - Cancel an order by client order ID\r\n- `cancel_orders_by_cloid/1`, `cancel_orders_by_cloid/2` - Cancel multiple orders by client order IDs\r\n- `modify_order/2`, `modify_order/3` - Modify an existing order\r\n- `modify_multiple_orders/1`, `modify_multiple_orders/2` - Modify multiple orders","ref":"Hyperliquid.Api.Exchange.html#module-order-management"},{"type":"module","title":"Account Management - Hyperliquid.Api.Exchange","doc":"- `update_leverage/3` - Update leverage for an asset\r\n- `update_isolated_margin/3` - Update isolated margin for an asset\r\n- `spot_perp_transfer/2` - Transfer between spot and perpetual accounts\r\n- `vault_transfer/3` - Transfer to/from a vault\r\n- `create_sub_account/1` - Create a sub-account\r\n- `sub_account_transfer/3` - Transfer funds to/from a sub-account\r\n- `sub_account_spot_transfer/4` - Transfer spot tokens to/from a sub-account","ref":"Hyperliquid.Api.Exchange.html#module-account-management"},{"type":"module","title":"Withdrawal and Transfers - Hyperliquid.Api.Exchange","doc":"- `usd_send/3` - Send USD to another address\r\n- `spot_send/4` - Send spot tokens to another address\r\n- `withdraw_from_bridge/3` - Withdraw funds from the bridge\r\n\r\nAll functions return a tuple `{:ok, result}` on success, or `{:error, details}` on failure.","ref":"Hyperliquid.Api.Exchange.html#module-withdrawal-and-transfers"},{"type":"function","title":"Hyperliquid.Api.Exchange.api_base/0","doc":"","ref":"Hyperliquid.Api.Exchange.html#api_base/0"},{"type":"function","title":"Hyperliquid.Api.Exchange.cancel_order/3","doc":"Cancels a single order.","ref":"Hyperliquid.Api.Exchange.html#cancel_order/3"},{"type":"function","title":"Parameters - Hyperliquid.Api.Exchange.cancel_order/3","doc":"- `asset`: Integer representing the asset's index in the coin list\r\n- `oid`: The order ID to cancel\r\n- `vault_address`: Optional vault address","ref":"Hyperliquid.Api.Exchange.html#cancel_order/3-parameters"},{"type":"function","title":"Example - Hyperliquid.Api.Exchange.cancel_order/3","doc":"iex> Hyperliquid.Api.Exchange.cancel_order(5, 123)\r\n    {:ok, %{...}}","ref":"Hyperliquid.Api.Exchange.html#cancel_order/3-example"},{"type":"function","title":"Hyperliquid.Api.Exchange.cancel_order_by_cloid/3","doc":"Cancels order by cloid.","ref":"Hyperliquid.Api.Exchange.html#cancel_order_by_cloid/3"},{"type":"function","title":"Parameters - Hyperliquid.Api.Exchange.cancel_order_by_cloid/3","doc":"- `asset`: Integer representing the asset's index in the coin list\r\n- `cloid`: The cloid to cancel\r\n- `vault_address`: Optional vault address","ref":"Hyperliquid.Api.Exchange.html#cancel_order_by_cloid/3-parameters"},{"type":"function","title":"Example - Hyperliquid.Api.Exchange.cancel_order_by_cloid/3","doc":"iex> Hyperliquid.Api.Exchange.cancel_order_by_cloid(5, \"0x123\")\r\n    {:ok, %{...}}","ref":"Hyperliquid.Api.Exchange.html#cancel_order_by_cloid/3-example"},{"type":"function","title":"Hyperliquid.Api.Exchange.cancel_orders/2","doc":"Cancels multiple orders.","ref":"Hyperliquid.Api.Exchange.html#cancel_orders/2"},{"type":"function","title":"Parameters - Hyperliquid.Api.Exchange.cancel_orders/2","doc":"- `cancels`: List of orders to cancel\r\n- `vault_address`: Optional vault address","ref":"Hyperliquid.Api.Exchange.html#cancel_orders/2-parameters"},{"type":"function","title":"Example - Hyperliquid.Api.Exchange.cancel_orders/2","doc":"iex> Hyperliquid.Api.Exchange.cancel_orders([%{a: 5, o: 123}, %{a: 5, o: 456}])\r\n    {:ok, %{...}}","ref":"Hyperliquid.Api.Exchange.html#cancel_orders/2-example"},{"type":"function","title":"Hyperliquid.Api.Exchange.cancel_orders_by_cloid/2","doc":"","ref":"Hyperliquid.Api.Exchange.html#cancel_orders_by_cloid/2"},{"type":"function","title":"Hyperliquid.Api.Exchange.create_sub_account/1","doc":"Creates a new sub-account.","ref":"Hyperliquid.Api.Exchange.html#create_sub_account/1"},{"type":"function","title":"Parameters - Hyperliquid.Api.Exchange.create_sub_account/1","doc":"- `name`: The name for the new sub-account","ref":"Hyperliquid.Api.Exchange.html#create_sub_account/1-parameters"},{"type":"function","title":"Example - Hyperliquid.Api.Exchange.create_sub_account/1","doc":"iex> Hyperliquid.Api.Exchange.create_sub_account(\"trading_bot_1\")\r\n    {:ok, %{...}}","ref":"Hyperliquid.Api.Exchange.html#create_sub_account/1-example"},{"type":"function","title":"Hyperliquid.Api.Exchange.endpoint/0","doc":"","ref":"Hyperliquid.Api.Exchange.html#endpoint/0"},{"type":"function","title":"Hyperliquid.Api.Exchange.mainnet?/0","doc":"","ref":"Hyperliquid.Api.Exchange.html#mainnet?/0"},{"type":"function","title":"Hyperliquid.Api.Exchange.modify_multiple_orders/2","doc":"","ref":"Hyperliquid.Api.Exchange.html#modify_multiple_orders/2"},{"type":"function","title":"Hyperliquid.Api.Exchange.modify_order/3","doc":"Modifies an existing order.","ref":"Hyperliquid.Api.Exchange.html#modify_order/3"},{"type":"function","title":"Parameters - Hyperliquid.Api.Exchange.modify_order/3","doc":"- `oid`: The order ID to modify\r\n- `order`: A map containing the new order details\r\n- `vault_address`: Optional vault address","ref":"Hyperliquid.Api.Exchange.html#modify_order/3-parameters"},{"type":"function","title":"Example - Hyperliquid.Api.Exchange.modify_order/3","doc":"iex> Hyperliquid.Api.Exchange.modify_order(123, order)\r\n    {:ok, %{...}}","ref":"Hyperliquid.Api.Exchange.html#modify_order/3-example"},{"type":"function","title":"Hyperliquid.Api.Exchange.place_order/3","doc":"Places one or multiple orders.","ref":"Hyperliquid.Api.Exchange.html#place_order/3"},{"type":"function","title":"Parameters - Hyperliquid.Api.Exchange.place_order/3","doc":"- `order`: A single order or a list of orders\r\n- `grouping`: Order grouping (default: \"na\")\r\n- `vault_address`: Optional vault address","ref":"Hyperliquid.Api.Exchange.html#place_order/3-parameters"},{"type":"function","title":"Examples - Hyperliquid.Api.Exchange.place_order/3","doc":"iex> Hyperliquid.Api.Exchange.place_order(order)\r\n    {:ok,\r\n      %{\r\n        \"response\" => %{\r\n          \"data\" => %{\r\n            \"statuses\" => [\r\n              %{\"filled\" => %{\"avgPx\" => \"115.17\", \"oid\" => 18422439200, \"totalSz\" => \"1.0\"}}\r\n            ]\r\n          },\r\n          \"type\" => \"order\"\r\n        },\r\n        \"status\" => \"ok\"\r\n      }}","ref":"Hyperliquid.Api.Exchange.html#place_order/3-examples"},{"type":"function","title":"Hyperliquid.Api.Exchange.post/1","doc":"","ref":"Hyperliquid.Api.Exchange.html#post/1"},{"type":"function","title":"Hyperliquid.Api.Exchange.post_action/1","doc":"","ref":"Hyperliquid.Api.Exchange.html#post_action/1"},{"type":"function","title":"Hyperliquid.Api.Exchange.post_action/2","doc":"","ref":"Hyperliquid.Api.Exchange.html#post_action/2"},{"type":"function","title":"Hyperliquid.Api.Exchange.post_action/3","doc":"","ref":"Hyperliquid.Api.Exchange.html#post_action/3"},{"type":"function","title":"Hyperliquid.Api.Exchange.post_action/4","doc":"","ref":"Hyperliquid.Api.Exchange.html#post_action/4"},{"type":"function","title":"Hyperliquid.Api.Exchange.post_signed/1","doc":"","ref":"Hyperliquid.Api.Exchange.html#post_signed/1"},{"type":"function","title":"Hyperliquid.Api.Exchange.set_referrer/1","doc":"","ref":"Hyperliquid.Api.Exchange.html#set_referrer/1"},{"type":"function","title":"Hyperliquid.Api.Exchange.spot_perp_transfer/2","doc":"Transfers funds between spot and perpetual accounts.","ref":"Hyperliquid.Api.Exchange.html#spot_perp_transfer/2"},{"type":"function","title":"Parameters - Hyperliquid.Api.Exchange.spot_perp_transfer/2","doc":"- `amount`: The amount to transfer (in USDC)\r\n- `to_perp`: Boolean indicating the direction of transfer (true for spot to perp, false for perp to spot)","ref":"Hyperliquid.Api.Exchange.html#spot_perp_transfer/2-parameters"},{"type":"function","title":"Example - Hyperliquid.Api.Exchange.spot_perp_transfer/2","doc":"iex> Hyperliquid.Api.Exchange.spot_perp_transfer(1000, true)\r\n    {:ok, %{...}}","ref":"Hyperliquid.Api.Exchange.html#spot_perp_transfer/2-example"},{"type":"function","title":"Hyperliquid.Api.Exchange.spot_send/4","doc":"","ref":"Hyperliquid.Api.Exchange.html#spot_send/4"},{"type":"function","title":"Hyperliquid.Api.Exchange.sub_account_spot_transfer/4","doc":"Transfers spot tokens to or from a sub-account.","ref":"Hyperliquid.Api.Exchange.html#sub_account_spot_transfer/4"},{"type":"function","title":"Parameters - Hyperliquid.Api.Exchange.sub_account_spot_transfer/4","doc":"- `user`: The address or identifier of the sub-account\r\n- `is_deposit`: Boolean indicating whether it's a deposit (true) or withdrawal (false)\r\n- `token`: The token to transfer (e.g., \"BTC\", \"ETH\")\r\n- `amount`: The amount of the token to transfer","ref":"Hyperliquid.Api.Exchange.html#sub_account_spot_transfer/4-parameters"},{"type":"function","title":"Example - Hyperliquid.Api.Exchange.sub_account_spot_transfer/4","doc":"iex> Hyperliquid.Api.Exchange.sub_account_spot_transfer(\"0x9876...\", true, \"BTC\", 0.1)\r\n    {:ok, %{...}}","ref":"Hyperliquid.Api.Exchange.html#sub_account_spot_transfer/4-example"},{"type":"function","title":"Hyperliquid.Api.Exchange.sub_account_transfer/3","doc":"Transfers funds to or from a sub-account.","ref":"Hyperliquid.Api.Exchange.html#sub_account_transfer/3"},{"type":"function","title":"Parameters - Hyperliquid.Api.Exchange.sub_account_transfer/3","doc":"- `user`: The address or identifier of the sub-account\r\n- `is_deposit`: Boolean indicating whether it's a deposit (true) or withdrawal (false)\r\n- `amount_usd`: The amount to transfer in USD cents (e.g., 1_000_000 = $1)","ref":"Hyperliquid.Api.Exchange.html#sub_account_transfer/3-parameters"},{"type":"function","title":"Example - Hyperliquid.Api.Exchange.sub_account_transfer/3","doc":"iex> Hyperliquid.Api.Exchange.sub_account_transfer(\"0x5678...\", true, 1_000_000)\r\n    {:ok, %{...}}","ref":"Hyperliquid.Api.Exchange.html#sub_account_transfer/3-example"},{"type":"function","title":"Hyperliquid.Api.Exchange.update_isolated_margin/3","doc":"Updates the isolated margin for a specific asset.","ref":"Hyperliquid.Api.Exchange.html#update_isolated_margin/3"},{"type":"function","title":"Parameters - Hyperliquid.Api.Exchange.update_isolated_margin/3","doc":"- `asset`: Integer representing the asset's index in the coin list\r\n- `is_buy`: Boolean indicating whether it's a buy position\r\n- `ntli`: The new notional total liability increase","ref":"Hyperliquid.Api.Exchange.html#update_isolated_margin/3-parameters"},{"type":"function","title":"Example - Hyperliquid.Api.Exchange.update_isolated_margin/3","doc":"iex> Hyperliquid.Api.Exchange.update_isolated_margin(1, true, 1000)\r\n    {:ok, %{...}}","ref":"Hyperliquid.Api.Exchange.html#update_isolated_margin/3-example"},{"type":"function","title":"Hyperliquid.Api.Exchange.update_leverage/3","doc":"Updates the leverage for a specific asset.","ref":"Hyperliquid.Api.Exchange.html#update_leverage/3"},{"type":"function","title":"Parameters - Hyperliquid.Api.Exchange.update_leverage/3","doc":"- `asset`: Integer representing the asset's index in the coin list\r\n- `is_cross`: Boolean indicating whether to use cross margin\r\n- `leverage`: The new leverage value","ref":"Hyperliquid.Api.Exchange.html#update_leverage/3-parameters"},{"type":"function","title":"Example - Hyperliquid.Api.Exchange.update_leverage/3","doc":"iex> Hyperliquid.Api.Exchange.update_leverage(1, true, 10)\r\n    {:ok, %{...}}","ref":"Hyperliquid.Api.Exchange.html#update_leverage/3-example"},{"type":"function","title":"Hyperliquid.Api.Exchange.usd_send/3","doc":"","ref":"Hyperliquid.Api.Exchange.html#usd_send/3"},{"type":"function","title":"Hyperliquid.Api.Exchange.vault_transfer/3","doc":"Transfers funds to or from a vault.","ref":"Hyperliquid.Api.Exchange.html#vault_transfer/3"},{"type":"function","title":"Parameters - Hyperliquid.Api.Exchange.vault_transfer/3","doc":"- `vault_address`: The address of the vault\r\n- `is_deposit`: Boolean indicating whether it's a deposit (true) or withdrawal (false)\r\n- `amount_usd`: The amount to transfer in USD (positive for transfer, negative for withdraw)","ref":"Hyperliquid.Api.Exchange.html#vault_transfer/3-parameters"},{"type":"function","title":"Example - Hyperliquid.Api.Exchange.vault_transfer/3","doc":"iex> Hyperliquid.Api.Exchange.vault_transfer(\"0x1234...\", true, 1000)\r\n    {:ok, %{...}}","ref":"Hyperliquid.Api.Exchange.html#vault_transfer/3-example"},{"type":"function","title":"Hyperliquid.Api.Exchange.withdraw_from_bridge/3","doc":"Withdraws funds from the bridge.","ref":"Hyperliquid.Api.Exchange.html#withdraw_from_bridge/3"},{"type":"function","title":"Parameters - Hyperliquid.Api.Exchange.withdraw_from_bridge/3","doc":"- `destination`: The destination address\r\n- `amount`: The amount to withdraw\r\n- `time`: The timestamp for the withdrawal","ref":"Hyperliquid.Api.Exchange.html#withdraw_from_bridge/3-parameters"},{"type":"function","title":"Returns - Hyperliquid.Api.Exchange.withdraw_from_bridge/3","doc":"`{:ok, result}` on success, where `result` contains the response from the API.\r\n`{:error, details}` on failure.","ref":"Hyperliquid.Api.Exchange.html#withdraw_from_bridge/3-returns"},{"type":"function","title":"Example - Hyperliquid.Api.Exchange.withdraw_from_bridge/3","doc":"iex> Hyperliquid.Api.Exchange.withdraw_from_bridge(\"0x1234...\", 1000000, 1625097600)\r\n    {:ok, %{...}}","ref":"Hyperliquid.Api.Exchange.html#withdraw_from_bridge/3-example"},{"type":"module","title":"Hyperliquid.Api.Explorer","doc":"Module for interacting with the Hyperliquid Explorer API endpoints.\r\n\r\nThis module provides functions to query various details from the Hyperliquid blockchain,\r\nincluding block details, transaction details, and user details.\r\n\r\nIt uses the `Hyperliquid.Api` macro to set up the basic API interaction functionality.","ref":"Hyperliquid.Api.Explorer.html"},{"type":"module","title":"Usage - Hyperliquid.Api.Explorer","doc":"You can use this module to make queries to the Explorer API:\r\n\r\n    Hyperliquid.Api.Explorer.block_details(12345)\r\n    Hyperliquid.Api.Explorer.tx_details(\"0x1234...\")\r\n    Hyperliquid.Api.Explorer.user_details(\"0xabcd...\")","ref":"Hyperliquid.Api.Explorer.html#module-usage"},{"type":"module","title":"Functions - Hyperliquid.Api.Explorer","doc":"- `block_details/1` - Retrieve details for a specific block\r\n- `tx_details/1` - Retrieve details for a specific transaction\r\n- `user_details/1` - Retrieve details for a specific user address\r\n\r\nAll functions return a tuple `{:ok, result}` on success, or `{:error, details}` on failure.","ref":"Hyperliquid.Api.Explorer.html#module-functions"},{"type":"function","title":"Hyperliquid.Api.Explorer.api_base/0","doc":"","ref":"Hyperliquid.Api.Explorer.html#api_base/0"},{"type":"function","title":"Hyperliquid.Api.Explorer.block_details/1","doc":"Retrieves details for a specific block.","ref":"Hyperliquid.Api.Explorer.html#block_details/1"},{"type":"function","title":"Parameters - Hyperliquid.Api.Explorer.block_details/1","doc":"- `block`: The block height to query","ref":"Hyperliquid.Api.Explorer.html#block_details/1-parameters"},{"type":"function","title":"Example - Hyperliquid.Api.Explorer.block_details/1","doc":"iex> Hyperliquid.Api.Explorer.block_details(12345)\r\n    {:ok, %{\r\n      \"blockDetails\" => %{\r\n        \"blockTime\" => 1677437426106,\r\n        \"hash\" => \"0x0b2c0480a44085b1b3206fafd19634e8ed435b02d0c1962de0616838fe13f817\",\r\n        \"height\" => 12345,\r\n        \"numTxs\" => 1,\r\n        \"proposer\" => \"3BFD93BEAF77A51598FEA7BA084DDD2E798EC37A\",\r\n        \"txs\" => [\r\n          %{\r\n            \"action\" => %{\"cancels\" => [%{\"a\" => 3, \"o\" => 23482}], \"type\" => \"cancel\"},\r\n            \"block\" => 12345,\r\n            \"error\" => nil,\r\n            \"hash\" => \"0x5e2593db2fe88b32270f02303900005e650d7594bf1154b1b3b7b30e0137426f\",\r\n            \"time\" => 1677437426106,\r\n            \"user\" => \"0xb7b6f3cea3f66bf525f5d8f965f6dbf6d9b017b2\"\r\n          }\r\n        ]\r\n      },\r\n      \"type\" => \"blockDetails\"\r\n    }}","ref":"Hyperliquid.Api.Explorer.html#block_details/1-example"},{"type":"function","title":"Hyperliquid.Api.Explorer.endpoint/0","doc":"","ref":"Hyperliquid.Api.Explorer.html#endpoint/0"},{"type":"function","title":"Hyperliquid.Api.Explorer.mainnet?/0","doc":"","ref":"Hyperliquid.Api.Explorer.html#mainnet?/0"},{"type":"function","title":"Hyperliquid.Api.Explorer.post/1","doc":"","ref":"Hyperliquid.Api.Explorer.html#post/1"},{"type":"function","title":"Hyperliquid.Api.Explorer.post_action/1","doc":"","ref":"Hyperliquid.Api.Explorer.html#post_action/1"},{"type":"function","title":"Hyperliquid.Api.Explorer.post_action/2","doc":"","ref":"Hyperliquid.Api.Explorer.html#post_action/2"},{"type":"function","title":"Hyperliquid.Api.Explorer.post_action/3","doc":"","ref":"Hyperliquid.Api.Explorer.html#post_action/3"},{"type":"function","title":"Hyperliquid.Api.Explorer.post_action/4","doc":"","ref":"Hyperliquid.Api.Explorer.html#post_action/4"},{"type":"function","title":"Hyperliquid.Api.Explorer.post_signed/1","doc":"","ref":"Hyperliquid.Api.Explorer.html#post_signed/1"},{"type":"function","title":"Hyperliquid.Api.Explorer.tx_details/1","doc":"Retrieves details for a specific transaction.","ref":"Hyperliquid.Api.Explorer.html#tx_details/1"},{"type":"function","title":"Parameters - Hyperliquid.Api.Explorer.tx_details/1","doc":"- `hash`: The transaction hash to query","ref":"Hyperliquid.Api.Explorer.html#tx_details/1-parameters"},{"type":"function","title":"Example - Hyperliquid.Api.Explorer.tx_details/1","doc":"iex> Hyperliquid.Api.Explorer.tx_details(\"0xf94afe652b34cc43d688040cb9571100001ca826f770b3adb1358e2c82d59be8\")\r\n    {:ok, %{\r\n      \"tx\" => %{\r\n        \"action\" => %{\r\n          \"cancels\" => [%{\"asset\" => 75, \"cloid\" => \"0x00000000000003800076757960710291\"}],\r\n          \"type\" => \"cancelByCloid\"\r\n        },\r\n        \"block\" => 213473041,\r\n        \"error\" => nil,\r\n        \"hash\" => \"0xf94afe652b34cc43d688040cb9571100001ca826f770b3adb1358e2c82d59be8\",\r\n        \"time\" => 1719979999193,\r\n        \"user\" => \"0xaf9f722a676230cc44045efe26fe9a85801ca4fa\"\r\n      },\r\n      \"type\" => \"txDetails\"\r\n    }}","ref":"Hyperliquid.Api.Explorer.html#tx_details/1-example"},{"type":"function","title":"Hyperliquid.Api.Explorer.user_details/1","doc":"Retrieves details for a specific user address.","ref":"Hyperliquid.Api.Explorer.html#user_details/1"},{"type":"function","title":"Parameters - Hyperliquid.Api.Explorer.user_details/1","doc":"- `user_address`: The user address to query","ref":"Hyperliquid.Api.Explorer.html#user_details/1-parameters"},{"type":"function","title":"Example - Hyperliquid.Api.Explorer.user_details/1","doc":"iex> Hyperliquid.Api.Explorer.user_details(\"0xabcd...\")\r\n    {:ok, %{\r\n      \"txs\" => [\r\n        %{\r\n          \"action\" => %{\"cancels\" => [%{\"a\" => 136, \"o\" => 26403012371}], \"type\" => \"cancel\"},\r\n          \"block\" => 195937903,\r\n          \"error\" => nil,\r\n          \"hash\" => \"0x62307db3f7e254b668fe040badc66f017c00e1fe11758901a25f7a562f7c019b\",\r\n          \"time\" => 1718631244781,\r\n          \"user\" => \"0x25c32751bc8de15e282919ba3946def63c044dea\"\r\n        }\r\n      ],\r\n      \"type\" => \"userDetails\"\r\n    }}","ref":"Hyperliquid.Api.Explorer.html#user_details/1-example"},{"type":"module","title":"Hyperliquid.Api.Info","doc":"Info endpoints.","ref":"Hyperliquid.Api.Info.html"},{"type":"function","title":"Hyperliquid.Api.Info.agents/1","doc":"","ref":"Hyperliquid.Api.Info.html#agents/1"},{"type":"function","title":"Hyperliquid.Api.Info.all_mids/0","doc":"","ref":"Hyperliquid.Api.Info.html#all_mids/0"},{"type":"function","title":"Hyperliquid.Api.Info.api_base/0","doc":"","ref":"Hyperliquid.Api.Info.html#api_base/0"},{"type":"function","title":"Hyperliquid.Api.Info.candle_snapshot/4","doc":"","ref":"Hyperliquid.Api.Info.html#candle_snapshot/4"},{"type":"function","title":"Hyperliquid.Api.Info.clearinghouse_state/1","doc":"","ref":"Hyperliquid.Api.Info.html#clearinghouse_state/1"},{"type":"function","title":"Hyperliquid.Api.Info.endpoint/0","doc":"","ref":"Hyperliquid.Api.Info.html#endpoint/0"},{"type":"function","title":"Hyperliquid.Api.Info.eth_faucet/1","doc":"","ref":"Hyperliquid.Api.Info.html#eth_faucet/1"},{"type":"function","title":"Hyperliquid.Api.Info.funding_history/3","doc":"","ref":"Hyperliquid.Api.Info.html#funding_history/3"},{"type":"function","title":"Hyperliquid.Api.Info.get_orders/1","doc":"","ref":"Hyperliquid.Api.Info.html#get_orders/1"},{"type":"function","title":"Hyperliquid.Api.Info.get_orders_fe/1","doc":"","ref":"Hyperliquid.Api.Info.html#get_orders_fe/1"},{"type":"function","title":"Hyperliquid.Api.Info.is_vip/1","doc":"","ref":"Hyperliquid.Api.Info.html#is_vip/1"},{"type":"function","title":"Hyperliquid.Api.Info.l2_book/1","doc":"","ref":"Hyperliquid.Api.Info.html#l2_book/1"},{"type":"function","title":"Hyperliquid.Api.Info.leaderboard/0","doc":"","ref":"Hyperliquid.Api.Info.html#leaderboard/0"},{"type":"function","title":"Hyperliquid.Api.Info.mainnet?/0","doc":"","ref":"Hyperliquid.Api.Info.html#mainnet?/0"},{"type":"function","title":"Hyperliquid.Api.Info.meta/0","doc":"","ref":"Hyperliquid.Api.Info.html#meta/0"},{"type":"function","title":"Hyperliquid.Api.Info.meta_and_asset_ctxs/0","doc":"","ref":"Hyperliquid.Api.Info.html#meta_and_asset_ctxs/0"},{"type":"function","title":"Hyperliquid.Api.Info.order_by_id/2","doc":"","ref":"Hyperliquid.Api.Info.html#order_by_id/2"},{"type":"function","title":"Hyperliquid.Api.Info.portfolio/1","doc":"","ref":"Hyperliquid.Api.Info.html#portfolio/1"},{"type":"function","title":"Hyperliquid.Api.Info.post/1","doc":"","ref":"Hyperliquid.Api.Info.html#post/1"},{"type":"function","title":"Hyperliquid.Api.Info.post_action/1","doc":"","ref":"Hyperliquid.Api.Info.html#post_action/1"},{"type":"function","title":"Hyperliquid.Api.Info.post_action/2","doc":"","ref":"Hyperliquid.Api.Info.html#post_action/2"},{"type":"function","title":"Hyperliquid.Api.Info.post_action/3","doc":"","ref":"Hyperliquid.Api.Info.html#post_action/3"},{"type":"function","title":"Hyperliquid.Api.Info.post_action/4","doc":"","ref":"Hyperliquid.Api.Info.html#post_action/4"},{"type":"function","title":"Hyperliquid.Api.Info.post_signed/1","doc":"","ref":"Hyperliquid.Api.Info.html#post_signed/1"},{"type":"function","title":"Hyperliquid.Api.Info.predicted_fundings/0","doc":"","ref":"Hyperliquid.Api.Info.html#predicted_fundings/0"},{"type":"function","title":"Hyperliquid.Api.Info.referral_state/1","doc":"","ref":"Hyperliquid.Api.Info.html#referral_state/1"},{"type":"function","title":"Hyperliquid.Api.Info.spot_clearinghouse_state/1","doc":"","ref":"Hyperliquid.Api.Info.html#spot_clearinghouse_state/1"},{"type":"function","title":"Hyperliquid.Api.Info.spot_meta/0","doc":"","ref":"Hyperliquid.Api.Info.html#spot_meta/0"},{"type":"function","title":"Hyperliquid.Api.Info.spot_meta_and_asset_ctxs/0","doc":"","ref":"Hyperliquid.Api.Info.html#spot_meta_and_asset_ctxs/0"},{"type":"function","title":"Hyperliquid.Api.Info.sub_accounts/1","doc":"","ref":"Hyperliquid.Api.Info.html#sub_accounts/1"},{"type":"function","title":"Hyperliquid.Api.Info.tvl_breakdown/0","doc":"","ref":"Hyperliquid.Api.Info.html#tvl_breakdown/0"},{"type":"function","title":"Hyperliquid.Api.Info.user_fees/1","doc":"","ref":"Hyperliquid.Api.Info.html#user_fees/1"},{"type":"function","title":"Hyperliquid.Api.Info.user_fills/1","doc":"","ref":"Hyperliquid.Api.Info.html#user_fills/1"},{"type":"function","title":"Hyperliquid.Api.Info.user_funding/3","doc":"","ref":"Hyperliquid.Api.Info.html#user_funding/3"},{"type":"function","title":"Hyperliquid.Api.Info.user_non_funding_ledger_updates/1","doc":"","ref":"Hyperliquid.Api.Info.html#user_non_funding_ledger_updates/1"},{"type":"function","title":"Hyperliquid.Api.Info.user_rate_limit/1","doc":"","ref":"Hyperliquid.Api.Info.html#user_rate_limit/1"},{"type":"function","title":"Hyperliquid.Api.Info.user_twap_slice_fills/1","doc":"","ref":"Hyperliquid.Api.Info.html#user_twap_slice_fills/1"},{"type":"function","title":"Hyperliquid.Api.Info.user_vault_equities/1","doc":"","ref":"Hyperliquid.Api.Info.html#user_vault_equities/1"},{"type":"function","title":"Hyperliquid.Api.Info.user_web_data/1","doc":"","ref":"Hyperliquid.Api.Info.html#user_web_data/1"},{"type":"function","title":"Hyperliquid.Api.Info.vaults/1","doc":"","ref":"Hyperliquid.Api.Info.html#vaults/1"},{"type":"module","title":"Hyperliquid.Api.Subscription","doc":"Subscriptions and related helper methods.","ref":"Hyperliquid.Api.Subscription.html"},{"type":"function","title":"Hyperliquid.Api.Subscription.active_asset_ctx/1","doc":"","ref":"Hyperliquid.Api.Subscription.html#active_asset_ctx/1"},{"type":"function","title":"Hyperliquid.Api.Subscription.active_asset_data/2","doc":"","ref":"Hyperliquid.Api.Subscription.html#active_asset_data/2"},{"type":"function","title":"Hyperliquid.Api.Subscription.all_mids/0","doc":"","ref":"Hyperliquid.Api.Subscription.html#all_mids/0"},{"type":"function","title":"Hyperliquid.Api.Subscription.candle/2","doc":"","ref":"Hyperliquid.Api.Subscription.html#candle/2"},{"type":"function","title":"Hyperliquid.Api.Subscription.coin_topics/0","doc":"","ref":"Hyperliquid.Api.Subscription.html#coin_topics/0"},{"type":"function","title":"Hyperliquid.Api.Subscription.explorer_block/0","doc":"","ref":"Hyperliquid.Api.Subscription.html#explorer_block/0"},{"type":"function","title":"Hyperliquid.Api.Subscription.explorer_txs/0","doc":"","ref":"Hyperliquid.Api.Subscription.html#explorer_txs/0"},{"type":"function","title":"Hyperliquid.Api.Subscription.general_topics/0","doc":"","ref":"Hyperliquid.Api.Subscription.html#general_topics/0"},{"type":"function","title":"Hyperliquid.Api.Subscription.get_subject/1","doc":"","ref":"Hyperliquid.Api.Subscription.html#get_subject/1"},{"type":"function","title":"Hyperliquid.Api.Subscription.l2_book/1","doc":"","ref":"Hyperliquid.Api.Subscription.html#l2_book/1"},{"type":"function","title":"Hyperliquid.Api.Subscription.make_user_subs/1","doc":"","ref":"Hyperliquid.Api.Subscription.html#make_user_subs/1"},{"type":"function","title":"Hyperliquid.Api.Subscription.make_user_subs/2","doc":"","ref":"Hyperliquid.Api.Subscription.html#make_user_subs/2"},{"type":"function","title":"Hyperliquid.Api.Subscription.notification/1","doc":"","ref":"Hyperliquid.Api.Subscription.html#notification/1"},{"type":"function","title":"Hyperliquid.Api.Subscription.order_updates/1","doc":"","ref":"Hyperliquid.Api.Subscription.html#order_updates/1"},{"type":"function","title":"Hyperliquid.Api.Subscription.to_encoded_message/2","doc":"","ref":"Hyperliquid.Api.Subscription.html#to_encoded_message/2"},{"type":"function","title":"Hyperliquid.Api.Subscription.to_key/1","doc":"","ref":"Hyperliquid.Api.Subscription.html#to_key/1"},{"type":"function","title":"Hyperliquid.Api.Subscription.to_message/2","doc":"","ref":"Hyperliquid.Api.Subscription.html#to_message/2"},{"type":"function","title":"Hyperliquid.Api.Subscription.topics/0","doc":"","ref":"Hyperliquid.Api.Subscription.html#topics/0"},{"type":"function","title":"Hyperliquid.Api.Subscription.trades/1","doc":"","ref":"Hyperliquid.Api.Subscription.html#trades/1"},{"type":"function","title":"Hyperliquid.Api.Subscription.user_events/1","doc":"","ref":"Hyperliquid.Api.Subscription.html#user_events/1"},{"type":"function","title":"Hyperliquid.Api.Subscription.user_fills/1","doc":"","ref":"Hyperliquid.Api.Subscription.html#user_fills/1"},{"type":"function","title":"Hyperliquid.Api.Subscription.user_fundings/1","doc":"","ref":"Hyperliquid.Api.Subscription.html#user_fundings/1"},{"type":"function","title":"Hyperliquid.Api.Subscription.user_historical_orders/1","doc":"","ref":"Hyperliquid.Api.Subscription.html#user_historical_orders/1"},{"type":"function","title":"Hyperliquid.Api.Subscription.user_non_funding_ledger_updates/1","doc":"","ref":"Hyperliquid.Api.Subscription.html#user_non_funding_ledger_updates/1"},{"type":"function","title":"Hyperliquid.Api.Subscription.user_topics/0","doc":"","ref":"Hyperliquid.Api.Subscription.html#user_topics/0"},{"type":"function","title":"Hyperliquid.Api.Subscription.user_twap_history/1","doc":"","ref":"Hyperliquid.Api.Subscription.html#user_twap_history/1"},{"type":"function","title":"Hyperliquid.Api.Subscription.user_twap_slice_fills/1","doc":"","ref":"Hyperliquid.Api.Subscription.html#user_twap_slice_fills/1"},{"type":"function","title":"Hyperliquid.Api.Subscription.web_data/1","doc":"","ref":"Hyperliquid.Api.Subscription.html#web_data/1"},{"type":"type","title":"Hyperliquid.Api.Subscription.subscription/0","doc":"","ref":"Hyperliquid.Api.Subscription.html#t:subscription/0"},{"type":"type","title":"Hyperliquid.Api.Subscription.subscription_message/0","doc":"","ref":"Hyperliquid.Api.Subscription.html#t:subscription_message/0"},{"type":"module","title":"Hyperliquid.Cache","doc":"Application cache for storing asset lists and exchange meta information.\r\n\r\nThis module provides functions to initialize and manage a cache for Hyperliquid-related data,\r\nincluding asset information, exchange metadata, and utility functions for retrieving and\r\nmanipulating cached data.\r\n\r\nThe cache is implemented using Cachex and stores various pieces of information such as:\r\n- Exchange metadata\r\n- Spot market metadata\r\n- Asset mappings\r\n- Decimal precision information\r\n- Token information\r\n\r\nIt also provides utility functions for working with assets, tokens, and other cached data.","ref":"Hyperliquid.Cache.html"},{"type":"function","title":"Hyperliquid.Cache.all_mids/0","doc":"","ref":"Hyperliquid.Cache.html#all_mids/0"},{"type":"function","title":"Hyperliquid.Cache.asset_from_coin/1","doc":"Retrieves the asset index for a given coin symbol.","ref":"Hyperliquid.Cache.html#asset_from_coin/1"},{"type":"function","title":"Parameters - Hyperliquid.Cache.asset_from_coin/1","doc":"- `coin`: The coin symbol (e.g., \"BTC\", \"ETH\")","ref":"Hyperliquid.Cache.html#asset_from_coin/1-parameters"},{"type":"function","title":"Returns - Hyperliquid.Cache.asset_from_coin/1","doc":"The asset index corresponding to the given coin symbol, or nil if not found.","ref":"Hyperliquid.Cache.html#asset_from_coin/1-returns"},{"type":"function","title":"Example - Hyperliquid.Cache.asset_from_coin/1","doc":"iex> Hyperliquid.Cache.asset_from_coin(\"SOL\")\r\n    5","ref":"Hyperliquid.Cache.html#asset_from_coin/1-example"},{"type":"function","title":"Hyperliquid.Cache.asset_map/0","doc":"","ref":"Hyperliquid.Cache.html#asset_map/0"},{"type":"function","title":"Hyperliquid.Cache.clear/0","doc":"Clears all entries in the cache.","ref":"Hyperliquid.Cache.html#clear/0"},{"type":"function","title":"Hyperliquid.Cache.ctxs/0","doc":"","ref":"Hyperliquid.Cache.html#ctxs/0"},{"type":"function","title":"Hyperliquid.Cache.decimal_map/0","doc":"","ref":"Hyperliquid.Cache.html#decimal_map/0"},{"type":"function","title":"Hyperliquid.Cache.decimals_from_coin/1","doc":"","ref":"Hyperliquid.Cache.html#decimals_from_coin/1"},{"type":"function","title":"Hyperliquid.Cache.decr/2","doc":"Decrements a key's value in the cache by a given amount.","ref":"Hyperliquid.Cache.html#decr/2"},{"type":"function","title":"Hyperliquid.Cache.del/1","doc":"Removes a key from the cache.","ref":"Hyperliquid.Cache.html#del/1"},{"type":"function","title":"Hyperliquid.Cache.execute/1","doc":"","ref":"Hyperliquid.Cache.html#execute/1"},{"type":"function","title":"Hyperliquid.Cache.exists?/1","doc":"Checks if a key exists in the cache.","ref":"Hyperliquid.Cache.html#exists?/1"},{"type":"function","title":"Hyperliquid.Cache.get/1","doc":"Retrieves a value from the cache by key.","ref":"Hyperliquid.Cache.html#get/1"},{"type":"function","title":"Hyperliquid.Cache.get_and_update/2","doc":"Gets a value from the cache and updates it using the provided function.","ref":"Hyperliquid.Cache.html#get_and_update/2"},{"type":"function","title":"Hyperliquid.Cache.get_token_by_address/1","doc":"","ref":"Hyperliquid.Cache.html#get_token_by_address/1"},{"type":"function","title":"Hyperliquid.Cache.get_token_by_index/1","doc":"","ref":"Hyperliquid.Cache.html#get_token_by_index/1"},{"type":"function","title":"Hyperliquid.Cache.get_token_by_name/1","doc":"","ref":"Hyperliquid.Cache.html#get_token_by_name/1"},{"type":"function","title":"Hyperliquid.Cache.get_token_key/1","doc":"","ref":"Hyperliquid.Cache.html#get_token_key/1"},{"type":"function","title":"Hyperliquid.Cache.get_token_name_by_index/1","doc":"","ref":"Hyperliquid.Cache.html#get_token_name_by_index/1"},{"type":"function","title":"Hyperliquid.Cache.incr/2","doc":"Increments a key's value in the cache by a given amount.","ref":"Hyperliquid.Cache.html#incr/2"},{"type":"function","title":"Hyperliquid.Cache.increment/0","doc":"","ref":"Hyperliquid.Cache.html#increment/0"},{"type":"function","title":"Hyperliquid.Cache.init/0","doc":"Initializes the cache with api information.","ref":"Hyperliquid.Cache.html#init/0"},{"type":"function","title":"Hyperliquid.Cache.meta/0","doc":"","ref":"Hyperliquid.Cache.html#meta/0"},{"type":"function","title":"Hyperliquid.Cache.perps/0","doc":"","ref":"Hyperliquid.Cache.html#perps/0"},{"type":"function","title":"Hyperliquid.Cache.put/2","doc":"Puts a key-value pair into the cache.","ref":"Hyperliquid.Cache.html#put/2"},{"type":"function","title":"Hyperliquid.Cache.spot_ctxs/0","doc":"","ref":"Hyperliquid.Cache.html#spot_ctxs/0"},{"type":"function","title":"Hyperliquid.Cache.spot_meta/0","doc":"","ref":"Hyperliquid.Cache.html#spot_meta/0"},{"type":"function","title":"Hyperliquid.Cache.spot_pairs/0","doc":"","ref":"Hyperliquid.Cache.html#spot_pairs/0"},{"type":"function","title":"Hyperliquid.Cache.tokens/0","doc":"","ref":"Hyperliquid.Cache.html#tokens/0"},{"type":"function","title":"Hyperliquid.Cache.transaction/2","doc":"Executes a transaction for a set of keys.","ref":"Hyperliquid.Cache.html#transaction/2"},{"type":"module","title":"Hyperliquid.Cache.Updater","doc":"","ref":"Hyperliquid.Cache.Updater.html"},{"type":"function","title":"Hyperliquid.Cache.Updater.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Hyperliquid.Cache.Updater.html#child_spec/1"},{"type":"function","title":"Hyperliquid.Cache.Updater.init/1","doc":"","ref":"Hyperliquid.Cache.Updater.html#init/1"},{"type":"function","title":"Hyperliquid.Cache.Updater.set_update_interval/1","doc":"","ref":"Hyperliquid.Cache.Updater.html#set_update_interval/1"},{"type":"function","title":"Hyperliquid.Cache.Updater.start_link/1","doc":"","ref":"Hyperliquid.Cache.Updater.html#start_link/1"},{"type":"module","title":"Hyperliquid.Config","doc":"Configuration module for Hyperliquid application.","ref":"Hyperliquid.Config.html"},{"type":"function","title":"Hyperliquid.Config.api_base/0","doc":"Returns the base URL of the API.","ref":"Hyperliquid.Config.html#api_base/0"},{"type":"function","title":"Hyperliquid.Config.bridge_contract/0","doc":"Returns the bridge contract address, used for deposits.","ref":"Hyperliquid.Config.html#bridge_contract/0"},{"type":"function","title":"Hyperliquid.Config.mainnet?/0","doc":"Returns whether the application is running on mainnet.","ref":"Hyperliquid.Config.html#mainnet?/0"},{"type":"function","title":"Hyperliquid.Config.secret/0","doc":"Returns the private key.","ref":"Hyperliquid.Config.html#secret/0"},{"type":"function","title":"Hyperliquid.Config.ws_url/0","doc":"Returns the ws URL of the API.","ref":"Hyperliquid.Config.html#ws_url/0"},{"type":"module","title":"Hyperliquid.Encoder","doc":"Provides encoding functionality for Hyperliquid API actions.\r\n\r\nThis module contains various functions to encode structured data for different\r\nHyperliquid API actions. It supports encoding of orders, cancellations, modifications,\r\nand various other action types.","ref":"Hyperliquid.Encoder.html"},{"type":"module","title":"Key Features - Hyperliquid.Encoder","doc":"- Encodes different action types (order, cancel, modify, etc.)\r\n- Packs structured data for API requests\r\n- Supports various field encodings\r\n- Handles special cases like triggers and transfers\r\n- Provides utilities for binary data manipulation","ref":"Hyperliquid.Encoder.html#module-key-features"},{"type":"module","title":"Usage - Hyperliquid.Encoder","doc":"Most functions in this module are intended for internal use within the Hyperliquid\r\nAPI client. However, you may use some of the public functions if you need to\r\nmanually encode data for custom API interactions. Refer to the Signer module.\r\n\r\nExample:\r\n\r\n    iex> action = %{type: \"order\", orders: [...], grouping: \"na\"}\r\n    iex> nonce = 12345\r\n    iex> vault_address = \"0x1234...\"\r\n    iex> Hyperliquid.Encoder.pack_action(action, nonce, vault_address)\r\n\r\nNote: Ensure you understand the Hyperliquid API specifications when using\r\nthese encoding functions directly.","ref":"Hyperliquid.Encoder.html#module-usage"},{"type":"function","title":"Hyperliquid.Encoder.add_additional_bytes/2","doc":"","ref":"Hyperliquid.Encoder.html#add_additional_bytes/2"},{"type":"function","title":"Hyperliquid.Encoder.address_to_bytes/1","doc":"","ref":"Hyperliquid.Encoder.html#address_to_bytes/1"},{"type":"function","title":"Hyperliquid.Encoder.field/2","doc":"","ref":"Hyperliquid.Encoder.html#field/2"},{"type":"function","title":"Hyperliquid.Encoder.fields/2","doc":"","ref":"Hyperliquid.Encoder.html#fields/2"},{"type":"function","title":"Hyperliquid.Encoder.first_byte/1","doc":"","ref":"Hyperliquid.Encoder.html#first_byte/1"},{"type":"function","title":"Hyperliquid.Encoder.first_byte/2","doc":"","ref":"Hyperliquid.Encoder.html#first_byte/2"},{"type":"function","title":"Hyperliquid.Encoder.grouping/1","doc":"","ref":"Hyperliquid.Encoder.html#grouping/1"},{"type":"function","title":"Hyperliquid.Encoder.pack_action/3","doc":"","ref":"Hyperliquid.Encoder.html#pack_action/3"},{"type":"function","title":"Hyperliquid.Encoder.pack_cancel/1","doc":"","ref":"Hyperliquid.Encoder.html#pack_cancel/1"},{"type":"function","title":"Hyperliquid.Encoder.pack_cancels/1","doc":"","ref":"Hyperliquid.Encoder.html#pack_cancels/1"},{"type":"function","title":"Hyperliquid.Encoder.pack_modifies/1","doc":"","ref":"Hyperliquid.Encoder.html#pack_modifies/1"},{"type":"function","title":"Hyperliquid.Encoder.pack_modify/1","doc":"","ref":"Hyperliquid.Encoder.html#pack_modify/1"},{"type":"function","title":"Hyperliquid.Encoder.pack_order/1","doc":"","ref":"Hyperliquid.Encoder.html#pack_order/1"},{"type":"function","title":"Hyperliquid.Encoder.pack_orders/1","doc":"","ref":"Hyperliquid.Encoder.html#pack_orders/1"},{"type":"function","title":"Hyperliquid.Encoder.pack_transfer/1","doc":"","ref":"Hyperliquid.Encoder.html#pack_transfer/1"},{"type":"function","title":"Hyperliquid.Encoder.pack_trigger/1","doc":"","ref":"Hyperliquid.Encoder.html#pack_trigger/1"},{"type":"function","title":"Hyperliquid.Encoder.put_big_uint64/3","doc":"","ref":"Hyperliquid.Encoder.html#put_big_uint64/3"},{"type":"function","title":"Hyperliquid.Encoder.put_bytes/3","doc":"","ref":"Hyperliquid.Encoder.html#put_bytes/3"},{"type":"function","title":"Hyperliquid.Encoder.put_uint8/3","doc":"","ref":"Hyperliquid.Encoder.html#put_uint8/3"},{"type":"function","title":"Hyperliquid.Encoder.to_binary/1","doc":"","ref":"Hyperliquid.Encoder.html#to_binary/1"},{"type":"function","title":"Hyperliquid.Encoder.type/1","doc":"","ref":"Hyperliquid.Encoder.html#type/1"},{"type":"module","title":"Hyperliquid.Interval","doc":"Provides helper functions for handling time intervals supported by Hyperliquid.\r\n\r\nThis module offers utilities for working with various time intervals, from\r\n1 minute to 1 month. It includes functions to list supported intervals,\r\nconvert intervals to milliseconds, and calculate the next interval start time.","ref":"Hyperliquid.Interval.html"},{"type":"module","title":"Supported Intervals - Hyperliquid.Interval","doc":"The following intervals are supported:\r\n1m, 3m, 5m, 15m, 30m, 1h, 2h, 4h, 8h, 12h, 1d, 3d, 1w, 1M","ref":"Hyperliquid.Interval.html#module-supported-intervals"},{"type":"module","title":"Usage - Hyperliquid.Interval","doc":"You can use this module to:\r\n- Get a list of supported intervals\r\n- Convert intervals to milliseconds\r\n- Calculate the next start time for a given interval\r\n\r\nExample:\r\n\r\n    iex> Hyperliquid.Interval.list()\r\n    [\"1m\", \"3m\", \"5m\", \"15m\", \"30m\", \"1h\", \"2h\", \"4h\", \"8h\", \"12h\", \"1d\", \"3d\", \"1w\", \"1M\"]\r\n\r\n    iex> Hyperliquid.Interval.to_milliseconds(\"1h\")\r\n    3600000\r\n\r\n    iex> current_time = :os.system_time(:millisecond)\r\n    iex> Hyperliquid.Interval.next_start(current_time, \"15m\")\r\n    # Returns the next 15-minute interval start time","ref":"Hyperliquid.Interval.html#module-usage"},{"type":"function","title":"Hyperliquid.Interval.list/0","doc":"","ref":"Hyperliquid.Interval.html#list/0"},{"type":"function","title":"Hyperliquid.Interval.next_start/2","doc":"Rounds the current time up to the nearest interval period specified in milliseconds.","ref":"Hyperliquid.Interval.html#next_start/2"},{"type":"function","title":"Hyperliquid.Interval.to_milliseconds/1","doc":"Converts interval to milliseconds.","ref":"Hyperliquid.Interval.html#to_milliseconds/1"},{"type":"module","title":"Hyperliquid.Manager","doc":"Application manager responsible for handling WebSocket clients and subscriptions.\r\n\r\nThis module provides functionality to manage WebSocket connections, user subscriptions,\r\nand stream workers in the Hyperliquid application. It acts as a central point for\r\nmanaging the state of active connections and subscriptions.","ref":"Hyperliquid.Manager.html"},{"type":"module","title":"Key Features - Hyperliquid.Manager","doc":"- Initializes the application cache and starts initial streams\r\n- Manages user and non-user subscriptions\r\n- Provides utilities to start and stop stream workers\r\n- Handles automatic user subscription initialization\r\n- Offers functions to query the current state of subscriptions and workers","ref":"Hyperliquid.Manager.html#module-key-features"},{"type":"module","title":"Usage - Hyperliquid.Manager","doc":"This module is typically used to manage WebSocket connections and subscriptions,\r\nas well as to query the current state of workers.\r\n\r\nExample:\r\n\r\n    # Get all active subscriptions\r\n    Hyperliquid.Manager.get_all_active_subs()\r\n\r\n    # Start a new stream for a specific subscription\r\n    Hyperliquid.Manager.maybe_start_stream(%{type: \"allMids\"})\r\n\r\n    # Automatically start subscriptions for a user\r\n    Hyperliquid.Manager.auto_start_user(\"0x1234...\")","ref":"Hyperliquid.Manager.html#module-usage"},{"type":"function","title":"Hyperliquid.Manager.auto_start_user/2","doc":"","ref":"Hyperliquid.Manager.html#auto_start_user/2"},{"type":"function","title":"Hyperliquid.Manager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Hyperliquid.Manager.html#child_spec/1"},{"type":"function","title":"Hyperliquid.Manager.get_active_non_user_subs/0","doc":"","ref":"Hyperliquid.Manager.html#get_active_non_user_subs/0"},{"type":"function","title":"Hyperliquid.Manager.get_active_user_subs/0","doc":"","ref":"Hyperliquid.Manager.html#get_active_user_subs/0"},{"type":"function","title":"Hyperliquid.Manager.get_all_active_subs/0","doc":"","ref":"Hyperliquid.Manager.html#get_all_active_subs/0"},{"type":"function","title":"Hyperliquid.Manager.get_subbed_users/0","doc":"","ref":"Hyperliquid.Manager.html#get_subbed_users/0"},{"type":"function","title":"Hyperliquid.Manager.get_worker_ids/0","doc":"","ref":"Hyperliquid.Manager.html#get_worker_ids/0"},{"type":"function","title":"Hyperliquid.Manager.get_worker_pids/0","doc":"","ref":"Hyperliquid.Manager.html#get_worker_pids/0"},{"type":"function","title":"Hyperliquid.Manager.get_workers/0","doc":"","ref":"Hyperliquid.Manager.html#get_workers/0"},{"type":"function","title":"Hyperliquid.Manager.init/1","doc":"","ref":"Hyperliquid.Manager.html#init/1"},{"type":"function","title":"Hyperliquid.Manager.kill_worker/1","doc":"","ref":"Hyperliquid.Manager.html#kill_worker/1"},{"type":"function","title":"Hyperliquid.Manager.maybe_start_stream/1","doc":"","ref":"Hyperliquid.Manager.html#maybe_start_stream/1"},{"type":"function","title":"Hyperliquid.Manager.start_link/1","doc":"","ref":"Hyperliquid.Manager.html#start_link/1"},{"type":"function","title":"Hyperliquid.Manager.unsubscribe_all/1","doc":"","ref":"Hyperliquid.Manager.html#unsubscribe_all/1"},{"type":"module","title":"Hyperliquid.Orders","doc":"Provides helper methods for order creation and management.\r\n\r\nThis module offers a set of functions to facilitate various order operations, including:\r\n- Retrieving and calculating mid-prices\r\n- Creating market and limit orders\r\n- Handling order types and triggers\r\n- Managing position closures\r\n\r\nKey features:\r\n- Mid-price retrieval with caching mechanism\r\n- Slippage price calculation for market orders\r\n- Support for various order types (GTC, IOC, ALO)\r\n- Market buy and sell order creation\r\n- Limit order creation with customizable time-in-force\r\n- Position closing functionality\r\n\r\nThe module interacts with the Hyperliquid API and cache to ensure efficient\r\nand accurate order processing. It handles both perpetual and spot markets,\r\nand provides flexibility in order parameters such as size, price, and slippage.\r\n\r\nUsage examples:\r\n\r\n  # Retrieve mid-price for a coin\r\n  mid_price = Hyperliquid.Orders.get_midprice(\"SOL\")\r\n  135.545\r\n\r\n  # Place a market buy order\r\n  Hyperliquid.Orders.market_buy(\"ETH\", 1.0, \"0x123...\")\r\n  {:ok,\r\n    %{\r\n      \"response\" => %{\r\n        \"data\" => %{\r\n          \"statuses\" => [\r\n            %{\"filled\" => %{\"avgPx\" => \"128.03\", \"oid\" => 17114311614, \"totalSz\" => \"1.0\"}}\r\n          ]\r\n        },\r\n        \"type\" => \"order\"\r\n      },\r\n      \"status\" => \"ok\"\r\n    }}\r\n\r\n  # Place a limit sell order\r\n  Hyperliquid.Orders.limit_order(\"BTC\", 0.5, false, 50000, \"gtc\", false, \"0x123...\")\r\n  {:ok,\r\n    %{\r\n      \"response\" => %{\r\n        \"data\" => %{\"statuses\" => [%{\"resting\" => %{\"oid\" => 10030901240}}]},\r\n        \"type\" => \"order\"\r\n      },\r\n      \"status\" => \"ok\"\r\n    }}\r\n\r\n  # Close list of positions\r\n  {:ok, %{\"assetPositions\" => positions}} = Info.clearinghouse_state(\"0x123\")\r\n  Hyperliquid.Orders.market_close(positions)\r\n\r\n  # Close single position\r\n  positions\r\n  |> Enum.at(0)\r\n  |> Hyperliquid.Orders.market_close()\r\n\r\n  # Close all positions for an address\r\n  Hyperliquid.Orders.market_close(\"0x123...\")\r\n  [\r\n    ok: %{\r\n      \"response\" => %{\r\n        \"data\" => %{\r\n          \"statuses\" => [\r\n            %{\"filled\" => %{\"avgPx\" => \"148.07\", \"oid\" => 10934427319, \"totalSz\" => \"1.0\"}}\r\n          ]\r\n        },\r\n        \"type\" => \"order\"\r\n      },\r\n      \"status\" => \"ok\"\r\n    }\r\n  ]","ref":"Hyperliquid.Orders.html"},{"type":"function","title":"Hyperliquid.Orders.get_midprice/1","doc":"","ref":"Hyperliquid.Orders.html#get_midprice/1"},{"type":"function","title":"Hyperliquid.Orders.limit_order/7","doc":"","ref":"Hyperliquid.Orders.html#limit_order/7"},{"type":"function","title":"Hyperliquid.Orders.market_buy/3","doc":"","ref":"Hyperliquid.Orders.html#market_buy/3"},{"type":"function","title":"Hyperliquid.Orders.market_close/3","doc":"","ref":"Hyperliquid.Orders.html#market_close/3"},{"type":"function","title":"Hyperliquid.Orders.market_order/7","doc":"","ref":"Hyperliquid.Orders.html#market_order/7"},{"type":"function","title":"Hyperliquid.Orders.market_sell/3","doc":"","ref":"Hyperliquid.Orders.html#market_sell/3"},{"type":"function","title":"Hyperliquid.Orders.slippage_price/4","doc":"","ref":"Hyperliquid.Orders.html#slippage_price/4"},{"type":"function","title":"Hyperliquid.Orders.trigger_from_order_type/1","doc":"","ref":"Hyperliquid.Orders.html#trigger_from_order_type/1"},{"type":"module","title":"Hyperliquid.Orders.OrderWire","doc":"The OrderWire struct represents the essential parameters for placing an order on the\r\nHyperliquid exchange. It encapsulates all necessary information such as asset index,\r\nbuy/sell direction, price, size, and additional order properties.","ref":"Hyperliquid.Orders.OrderWire.html"},{"type":"module","title":"Struct Fields - Hyperliquid.Orders.OrderWire","doc":"* `:a` - Asset index (integer) representing the asset's position in the coin list\r\n  * `:b` - Boolean indicating if it's a buy order (true) or sell order (false)\r\n  * `:p` - Limit price for the order\r\n  * `:s` - Size of the order\r\n  * `:r` - Boolean indicating if it's a reduce-only order\r\n  * `:t` - Trigger conditions for the order\r\n  * `:c` - Client Order ID (optional)","ref":"Hyperliquid.Orders.OrderWire.html#module-struct-fields"},{"type":"module","title":"Usage - Hyperliquid.Orders.OrderWire","doc":"Create a new OrderWire struct:\r\n\r\n    iex> OrderWire.new(1, true, 50000, 1.0, false, %{limit: %{tif: \"Gtc\"}})\r\n    %OrderWire{a: 1, b: true, p: 50000, s: 1.0, r: false, t: %{limit: %{tif: \"Gtc\"}}, c: nil}\r\n\r\nPurify the OrderWire for API submission:\r\n\r\n    iex> order = OrderWire.new(1, true, 50000, 1.0, false, %{limit: %{tif: \"Gtc\"}})\r\n    iex> OrderWire.purify(order)\r\n    %{a: 1, b: true, p: \"50000\", s: \"1.0\", r: false, t: %{limit: %{tif: \"Gtc\"}}}","ref":"Hyperliquid.Orders.OrderWire.html#module-usage"},{"type":"module","title":"Full Contextual Example - Hyperliquid.Orders.OrderWire","doc":"The OrderWire struct is typically used within order placement functions in the Orders module. Here's an example\r\nof how it is used for a `limit_order` function:\r\n\r\n    def limit_order(coin, sz, is_buy?, px, tif \\ \"gtc\", reduce? \\ false, vault_address \\ nil) do\r\n      trigger = trigger_from_order_type(tif)\r\n      asset = Cache.asset_from_coin(coin)\r\n\r\n      OrderWire.new(asset, is_buy?, px, sz, reduce?, trigger)\r\n      |> OrderWire.purify()\r\n      |> Exchange.place_order(\"na\", vault_address)\r\n    end\r\n\r\nIn this example:\r\n1. The function takes order details as parameters.\r\n2. It determines the trigger type and fetches the asset index for the given coin.\r\n3. An OrderWire struct is created using the `new/7` function.\r\n4. The struct is then purified using the `purify/1` function.\r\n5. Finally, the purified order data is passed to an `Exchange.place_order/3` function for execution.\r\n\r\nThis demonstrates how OrderWire fits into the broader order placement process, encapsulating\r\norder details in a standardized format before submission to the exchange.\r\n\r\nNote: The `purify/1` function converts numeric values to strings and removes nil fields,\r\npreparing the order data for API submission. The asset index (`:a`) remains an integer.\r\n\r\nImportant: Ensure you're using the correct asset index based on the current coin list.","ref":"Hyperliquid.Orders.OrderWire.html#module-full-contextual-example"},{"type":"function","title":"Hyperliquid.Orders.OrderWire.new/7","doc":"Creates a new OrderWire struct.","ref":"Hyperliquid.Orders.OrderWire.html#new/7"},{"type":"function","title":"Hyperliquid.Orders.OrderWire.purify/1","doc":"Converts price and size to string if they are integer or float, and removes nil values from the struct.","ref":"Hyperliquid.Orders.OrderWire.html#purify/1"},{"type":"module","title":"Hyperliquid.Orders.PriceConverter","doc":"Provides helper methods for converting prices to the proper significant figures and decimal places.\r\n\r\nThis module offers functionality to convert prices for both perpetual (perp) and spot markets\r\nin the Hyperliquid system. It ensures that prices are formatted correctly with the appropriate\r\nnumber of significant figures and decimal places based on the market type.\r\n\r\nKey features:\r\n- Converts prices for both perpetual and spot markets\r\n- Handles input as strings, floats, or integers\r\n- Rounds to 5 significant figures for both market types\r\n- Limits decimal places to 6 for perpetual markets and 8 for spot markets\r\n- Provides error handling for invalid inputs or conversion failures\r\n\r\nUsage:\r\nThe main function `convert_price/2` takes a price value and an optional market type\r\n(defaulting to `:perp`). It returns either `{:ok, formatted_price}` or `{:error, reason}`.\r\n\r\nExample:\r\n    iex> Hyperliquid.Orders.PriceConverter.convert_price(1234.56789, :perp)\r\n    {:ok, \"1234.57\"}\r\n\r\n    iex> Hyperliquid.Orders.PriceConverter.convert_price(\"0.00012345\", :spot)\r\n    {:ok, \"0.00012345\"}","ref":"Hyperliquid.Orders.PriceConverter.html"},{"type":"function","title":"Hyperliquid.Orders.PriceConverter.convert_price/2","doc":"","ref":"Hyperliquid.Orders.PriceConverter.html#convert_price/2"},{"type":"module","title":"Hyperliquid.Signer","doc":"Hyperliquid.Signer provides methods for signing and constructing payloads for various\r\nHyperliquid operations.\r\n\r\nThis module includes functions for:\r\n- Generating action hashes\r\n- Constructing phantom agents\r\n- Signing L1 actions\r\n- Signing user-signed actions (e.g., spot transfers, USD transfers, withdrawals)\r\n- Signing agent approvals\r\n\r\nIt uses EIP-712 for structured data signing and provides utilities for handling\r\nsignatures and preparing data for signing.","ref":"Hyperliquid.Signer.html"},{"type":"function","title":"Hyperliquid.Signer.action_hash/3","doc":"","ref":"Hyperliquid.Signer.html#action_hash/3"},{"type":"function","title":"Hyperliquid.Signer.construct_phantom_agent/2","doc":"","ref":"Hyperliquid.Signer.html#construct_phantom_agent/2"},{"type":"function","title":"Hyperliquid.Signer.prepare_data/2","doc":"","ref":"Hyperliquid.Signer.html#prepare_data/2"},{"type":"function","title":"Hyperliquid.Signer.sign_agent/3","doc":"","ref":"Hyperliquid.Signer.html#sign_agent/3"},{"type":"function","title":"Hyperliquid.Signer.sign_l1_action/5","doc":"","ref":"Hyperliquid.Signer.html#sign_l1_action/5"},{"type":"function","title":"Hyperliquid.Signer.sign_spot_transfer_action/3","doc":"","ref":"Hyperliquid.Signer.html#sign_spot_transfer_action/3"},{"type":"function","title":"Hyperliquid.Signer.sign_usd_transfer_action/3","doc":"","ref":"Hyperliquid.Signer.html#sign_usd_transfer_action/3"},{"type":"function","title":"Hyperliquid.Signer.sign_user_signed_action/5","doc":"","ref":"Hyperliquid.Signer.html#sign_user_signed_action/5"},{"type":"function","title":"Hyperliquid.Signer.sign_withdraw_from_bridge_action/3","doc":"","ref":"Hyperliquid.Signer.html#sign_withdraw_from_bridge_action/3"},{"type":"function","title":"Hyperliquid.Signer.split_sig/1","doc":"Splits a hexadecimal signature into its components.","ref":"Hyperliquid.Signer.html#split_sig/1"},{"type":"function","title":"Parameters - Hyperliquid.Signer.split_sig/1","doc":"- `hex_signature`: The hexadecimal signature to split","ref":"Hyperliquid.Signer.html#split_sig/1-parameters"},{"type":"function","title":"Returns - Hyperliquid.Signer.split_sig/1","doc":"A map containing the signature components (r, s, v).","ref":"Hyperliquid.Signer.html#split_sig/1-returns"},{"type":"function","title":"Example - Hyperliquid.Signer.split_sig/1","doc":"iex> Hyperliquid.Signer.split_sig(\"0x1234...\")\r\n    %{r: \"0x...\", s: \"0x...\", v: 27}","ref":"Hyperliquid.Signer.html#split_sig/1-example"},{"type":"function","title":"Raises - Hyperliquid.Signer.split_sig/1","doc":"Raises an `ArgumentError` if the signature length is invalid or if the v value is unexpected.","ref":"Hyperliquid.Signer.html#split_sig/1-raises"},{"type":"module","title":"Hyperliquid.Streamer.Stream","doc":"WebSocket client for streaming data from the Hyperliquid API.\r\n\r\nThis module implements a WebSocket client that connects to the Hyperliquid API,\r\nmanages subscriptions, and processes incoming data. It handles connection\r\nmanagement, subscription requests, heartbeats, and message processing.","ref":"Hyperliquid.Streamer.Stream.html"},{"type":"module","title":"Key Features - Hyperliquid.Streamer.Stream","doc":"- Establishes and maintains WebSocket connections\r\n- Manages user and non-user subscriptions\r\n- Handles heartbeats and connection timeouts\r\n- Processes and broadcasts incoming messages\r\n- Supports dynamic subscription management","ref":"Hyperliquid.Streamer.Stream.html#module-key-features"},{"type":"module","title":"Usage - Hyperliquid.Streamer.Stream","doc":"This module is used to subscribe to ws events and can also support post requests.\r\nTypically this module shouldn't be called directly, as it is meant to be managed by the\r\nManager, errors may occur when used outside that context.\r\n\r\nTo subscribe to the broadcasts of ws events, you can refer to the subscription `type` for the\r\nchannel value to subscribe to in your own application.\r\n\r\nExample:\r\n\r\n    # Start a new stream with initial subscriptions\r\n    {:ok, pid} = Hyperliquid.Streamer.Stream.start_link([%{type: \"allMids\"}])\r\n\r\n    # Add a new subscription\r\n    Hyperliquid.Streamer.Stream.subscribe(pid, %{type: \"trades\", coin: \"BTC\"})\r\n\r\n    # Remove a subscription\r\n    Hyperliquid.Streamer.Stream.unsubscribe(pid, %{type: \"trades\", coin: \"BTC\"})","ref":"Hyperliquid.Streamer.Stream.html#module-usage"},{"type":"function","title":"Hyperliquid.Streamer.Stream.post/3","doc":"","ref":"Hyperliquid.Streamer.Stream.html#post/3"},{"type":"function","title":"Hyperliquid.Streamer.Stream.process_event/1","doc":"","ref":"Hyperliquid.Streamer.Stream.html#process_event/1"},{"type":"function","title":"Hyperliquid.Streamer.Stream.start_link/1","doc":"","ref":"Hyperliquid.Streamer.Stream.html#start_link/1"},{"type":"function","title":"Hyperliquid.Streamer.Stream.subscribe/2","doc":"","ref":"Hyperliquid.Streamer.Stream.html#subscribe/2"},{"type":"function","title":"Hyperliquid.Streamer.Stream.unsubscribe/2","doc":"","ref":"Hyperliquid.Streamer.Stream.html#unsubscribe/2"},{"type":"module","title":"Hyperliquid.Streamer.Supervisor","doc":"Supervisor for WebSocket stream processes in the Hyperliquid application.\r\n\r\nThis module implements a dynamic supervisor that manages WebSocket stream\r\nprocesses. It allows for dynamically starting and stopping stream processes,\r\nproviding flexibility in managing multiple WebSocket connections.","ref":"Hyperliquid.Streamer.Supervisor.html"},{"type":"module","title":"Key Features - Hyperliquid.Streamer.Supervisor","doc":"- Dynamically supervises WebSocket stream processes\r\n- Provides functions to start and stop individual stream processes\r\n- Allows querying of currently supervised children","ref":"Hyperliquid.Streamer.Supervisor.html#module-key-features"},{"type":"module","title":"Usage - Hyperliquid.Streamer.Supervisor","doc":"This supervisor is typically started as part of your application's supervision tree.\r\nIt can then be used to dynamically manage WebSocket stream processes.\r\n\r\nExample:\r\n\r\n    # Start the supervisor\r\n    {:ok, pid} = Hyperliquid.Streamer.Supervisor.start_link()\r\n\r\n    # Start a new stream process\r\n    {:ok, stream_pid} = Hyperliquid.Streamer.Supervisor.start_stream([%{type: \"allMids\"}])\r\n\r\n    # Stop a stream process\r\n    :ok = Hyperliquid.Streamer.Supervisor.stop_child(stream_pid)\r\n\r\nNote: This supervisor uses a :one_for_one strategy, meaning each child is\r\nsupervised independently.","ref":"Hyperliquid.Streamer.Supervisor.html#module-usage"},{"type":"function","title":"Hyperliquid.Streamer.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Hyperliquid.Streamer.Supervisor.html#child_spec/1"},{"type":"function","title":"Hyperliquid.Streamer.Supervisor.children/0","doc":"","ref":"Hyperliquid.Streamer.Supervisor.html#children/0"},{"type":"function","title":"Hyperliquid.Streamer.Supervisor.init/1","doc":"","ref":"Hyperliquid.Streamer.Supervisor.html#init/1"},{"type":"function","title":"Hyperliquid.Streamer.Supervisor.start_link/1","doc":"","ref":"Hyperliquid.Streamer.Supervisor.html#start_link/1"},{"type":"function","title":"Hyperliquid.Streamer.Supervisor.start_stream/1","doc":"","ref":"Hyperliquid.Streamer.Supervisor.html#start_stream/1"},{"type":"function","title":"Hyperliquid.Streamer.Supervisor.stop_child/1","doc":"","ref":"Hyperliquid.Streamer.Supervisor.html#stop_child/1"},{"type":"module","title":"Hyperliquid.Utils","doc":"Provides utility functions for the Hyperliquid application.\r\n\r\nThis module offers a collection of helper functions that are used across the\r\nHyperliquid application. It includes utilities for data manipulation,\r\nPubSub operations, number formatting, random ID generation, and hexadecimal\r\nconversions.","ref":"Hyperliquid.Utils.html"},{"type":"module","title":"Key Features - Hyperliquid.Utils","doc":"- Atomize keys in data structures\r\n- PubSub subscription and broadcasting\r\n- Number to string conversions with special float handling\r\n- Random client order ID (cloid) generation\r\n- Hexadecimal string manipulations\r\n- Timestamp generation","ref":"Hyperliquid.Utils.html#module-key-features"},{"type":"function","title":"Hyperliquid.Utils.atomize_keys/1","doc":"Utils for converting map keys to atoms.","ref":"Hyperliquid.Utils.html#atomize_keys/1"},{"type":"function","title":"Hyperliquid.Utils.float_to_string/1","doc":"","ref":"Hyperliquid.Utils.html#float_to_string/1"},{"type":"function","title":"Hyperliquid.Utils.get_timestamp/0","doc":"","ref":"Hyperliquid.Utils.html#get_timestamp/0"},{"type":"function","title":"Hyperliquid.Utils.hex_string_to_integer/1","doc":"","ref":"Hyperliquid.Utils.html#hex_string_to_integer/1"},{"type":"function","title":"Hyperliquid.Utils.make_cloid/0","doc":"","ref":"Hyperliquid.Utils.html#make_cloid/0"},{"type":"function","title":"Hyperliquid.Utils.numbers_to_strings/2","doc":"","ref":"Hyperliquid.Utils.html#numbers_to_strings/2"},{"type":"function","title":"Hyperliquid.Utils.subscribe/1","doc":"","ref":"Hyperliquid.Utils.html#subscribe/1"},{"type":"function","title":"Hyperliquid.Utils.to_full_hex/1","doc":"","ref":"Hyperliquid.Utils.html#to_full_hex/1"},{"type":"function","title":"Hyperliquid.Utils.to_hex/1","doc":"","ref":"Hyperliquid.Utils.html#to_hex/1"},{"type":"function","title":"Hyperliquid.Utils.trim_0x/1","doc":"","ref":"Hyperliquid.Utils.html#trim_0x/1"},{"type":"extras","title":"Changelog","doc":"0.1.3 - added functions to cache for easier access and allow intelisense to help you see whats available","ref":"changelog.html"},{"type":"extras","title":"License","doc":"MIT License\r\n\r\nCopyright (c) 2024 Steven Kedzior\r\n\r\nPermission is hereby granted, free of charge, to any person obtaining a copy\r\nof this software and associated documentation files (the \"Software\"), to deal\r\nin the Software without restriction, including without limitation the rights\r\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\r\ncopies of the Software, and to permit persons to whom the Software is\r\nfurnished to do so, subject to the following conditions:\r\n\r\nThe above copyright notice and this permission notice shall be included in all\r\ncopies or substantial portions of the Software.\r\n\r\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\r\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\r\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\r\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\r\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\r\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\r\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"Overview","doc":"# Hyperliquid\r\n\r\nHyperliquid is an Elixir-based library for interacting with the Hyperliquid decentralized exchange platform. It provides a set of modules and functions to manage WebSocket connections, handle orders, and interact with the Hyperliquid API.","ref":"readme.html"},{"type":"extras","title":"Features - Overview","doc":"- Order management (market, limit, and close orders)\r\n- Account operations (transfers, leverage adjustment, etc.)\r\n- Price conversion and formatting\r\n- Caching for efficient data access and improved performance\r\n- Dynamic subscription management\r\n- WebSocket streaming for real-time data","ref":"readme.html#features"},{"type":"extras","title":"Installation - Overview","doc":"Add `hyperliquid` to your list of dependencies in `mix.exs`:\r\n\r\n```elixir\r\ndef deps do\r\n  [\r\n    {:hyperliquid, \"~> 0.1.3\"}\r\n  ]\r\nend\r\n```","ref":"readme.html#installation"},{"type":"extras","title":"Livebook - Overview","doc":"To use in livebook, add the following to the notebook dependencies and setup section:\r\n\r\n```elixir\r\nMix.install([\r\n    {:hyperliquid, \"~> 0.1.3\"}\r\n  ],\r\n  config: [\r\n    hyperliquid: [private_key: \"YOUR_KEY_HERE\"]\r\n  ]\r\n)\r\n\r\n# You can override the default ws and http urls to use testnet\r\nMix.install([\r\n    {:hyperliquid, \"~> 0.1.3\"}\r\n  ],\r\n  config: [\r\n    hyperliquid: [\r\n      ws_url: \"wss://api.hyperliquid-testnet.xyz/ws\",\r\n      http_url: \"https://api.hyperliquid-testnet.xyz\",\r\n      private_key: \"YOUR_KEY_HERE\"\r\n    ]\r\n  ]\r\n)\r\n```","ref":"readme.html#livebook"},{"type":"extras","title":"Configuration - Overview","doc":"In `config/config.exs`, add Hyperliquid protocol host params to your config file\r\n\r\n```elixir\r\nconfig :hyperliquid,\r\n  private_key: \"YOUR_KEY_HERE\"\r\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - Overview","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Placing Orders - Overview","doc":"```elixir\r\n# Place a market sell order\r\nHyperliquid.Orders.market_sell(\"ETH\", 1)\r\n\r\n# Place a market buy order for a sub account (vault address)\r\nHyperliquid.Orders.market_buy(\"ETH\", 1, \"0x123...\")\r\n{:ok,\r\n  %{\r\n    \"response\" => %{\r\n      \"data\" => %{\r\n        \"statuses\" => [\r\n          %{\"filled\" => %{\"avgPx\" => \"128.03\", \"oid\" => 17114311614, \"totalSz\" => \"1.0\"}}\r\n        ]\r\n      },\r\n      \"type\" => \"order\"\r\n    },\r\n    \"status\" => \"ok\"\r\n  }}\r\n\r\n# Place a limit sell order\r\nHyperliquid.Orders.limit_order(\"BTC\", 0.5, false, 50000, \"gtc\", false)\r\n{:ok,\r\n  %{\r\n    \"response\" => %{\r\n      \"data\" => %{\"statuses\" => [%{\"resting\" => %{\"oid\" => 10030901240}}]},\r\n      \"type\" => \"order\"\r\n    },\r\n    \"status\" => \"ok\"\r\n  }}\r\n```","ref":"readme.html#placing-orders"},{"type":"extras","title":"Closing Positions - Overview","doc":"```elixir\r\n# Close list of positions\r\n{:ok, %{\"assetPositions\" => positions}} = Info.clearinghouse_state(\"0x123\")\r\nHyperliquid.Orders.market_close(positions)\r\n\r\n# Close single position\r\nposition = Enum.at(positions, 0)\r\nHyperliquid.Orders.market_close(position)\r\n{:ok, %{\r\n    \"response\" => %{\r\n      \"data\" => %{\r\n        \"statuses\" => [\r\n          %{\"filled\" => %{\"avgPx\" => \"148.07\", \"oid\" => 10934427319, \"totalSz\" => \"1.0\"}}\r\n        ]\r\n      },\r\n      \"type\" => \"order\"\r\n    },\r\n    \"status\" => \"ok\"\r\n  }}\r\n\r\n# Close all positions for an address\r\nHyperliquid.Orders.market_close(\"0x123...\")\r\n[\r\n  ok: %{\r\n    \"response\" => %{\r\n      \"data\" => %{\r\n        \"statuses\" => [\r\n          %{\"filled\" => %{\"avgPx\" => \"148.07\", \"oid\" => 10934427319, \"totalSz\" => \"1.0\"}}\r\n        ]\r\n      },\r\n      \"type\" => \"order\"\r\n    },\r\n    \"status\" => \"ok\"\r\n  }\r\n]\r\n```","ref":"readme.html#closing-positions"},{"type":"extras","title":"Streaming Data - Overview","doc":"To start a WebSocket stream:\r\n\r\n```elixir\r\n# Pass in a single sub or list of subs to start a new ws connection.\r\n{:ok, PID<0.408.0>} = Hyperliquid.Manager.maybe_start_stream(%{type: \"allMids\"})\r\n{:ok, PID<0.408.0>} = Hyperliquid.Manager.maybe_start_stream([sub_list])\r\n# The manager will check if the sub is currently already subscribed, and if not, open the connection.\r\n\r\n# To subscribe to a user address, we call auto_start_user\r\n{:ok, PID<0.408.0>} = Hyperliquid.Manager.auto_start_user(user_address)\r\n\r\n# Because we are limited to 10 unique user subscriptions, it is crucial to keep track of which users\r\n# are currently subbed to and that logic is handled internally by the manager but also available to be called externally.\r\nHyperliquid.Manager.get_subbed_users()\r\n[\"0x123...\"]\r\n\r\nHyperliquid.Manager.get_active_non_user_subs()\r\n[%{type: \"allMids\"}]\r\n\r\nHyperliquid.Manager.get_active_user_subs()\r\n[\r\n  %{type: \"userFundings\", user: \"0x123...\"},\r\n  %{type: \"userHistoricalOrders\", user: \"0x123...\"},\r\n  %{type: \"userTwapHistory\", user: \"0x123...\"},\r\n  %{type: \"userTwapSliceFills\", user: \"0x123...\"},\r\n  %{type: \"userNonFundingLedgerUpdates\", user: \"0x123...\"},\r\n  %{type: \"userFills\", user: \"0x123...\", aggregateByTime: false},\r\n  %{type: \"notification\", user: \"0x123...\"}\r\n]\r\n\r\nManager.get_workers()\r\n[PID<0.633.0>, PID<0.692.0>]\r\n```\r\n\r\nOnce a Manager has started, it will automatically subscribe to allMids and update the cache. \r\nThe Stream module is broadcasting each event it receives to the \"ws_event\" channel, \r\nto subscribe to these events in your own application, simply call subscribe like so:\r\n```elixir\r\nPhoenix.PubSub.subscribe(Hyperliquid.PubSub, channel)\r\n# also available is the shart hand method, via the Utils module.\r\nHyperliquid.Utils.subscribe(channel)\r\n```","ref":"readme.html#streaming-data"},{"type":"extras","title":"Cache - Overview","doc":"The application uses Cachex to handle in memory kv storage for fast and efficient lookup of values \r\nwe frequently need to place valid orders, one of those key items is the current mid price of each asset.\r\n\r\nWhen initialized, the Manager will make several requests to get this data, as well as subscribe to the \"allMids\" channel. \r\nThis ensures the latest mid price is always up to date and can be immediately accessable.\r\n\r\nQuick access utility functions.\r\n```elixir\r\ndef meta,         do: Cache.get(:meta)\r\ndef spot_meta,    do: Cache.get(:spot_meta)\r\ndef all_mids,     do: Cache.get(:all_mids)\r\ndef asset_map,    do: Cache.get(:asset_map)\r\ndef decimal_map,  do: Cache.get(:decimal_map)\r\ndef perps,        do: Cache.get(:perps)\r\ndef spot_pairs,   do: Cache.get(:spot_pairs)\r\ndef tokens,       do: Cache.get(:tokens)\r\ndef ctxs,         do: Cache.get(:ctxs)\r\ndef spot_ctxs,    do: Cache.get(:spot_ctxs)\r\n```\r\nYou may also note some commonly used util methods in the Cache which can be used like this:\r\n\r\n```elixir\r\nHyperliquid.Cache.asset_from_coin(\"SOL\")\r\n5\r\n\r\nHyperliquid.Cache.decimals_from_coin(\"SOL\")\r\n2\r\n\r\nHyperliquid.Cache.get_token_by_name(\"HFUN\")\r\n%{\r\n  \"evmContract\" => nil,\r\n  \"fullName\" => nil,\r\n  \"index\" => 2,\r\n  \"isCanonical\" => false,\r\n  \"name\" => \"HFUN\",\r\n  \"szDecimals\" => 2,\r\n  \"tokenId\" => \"0xbaf265ef389da684513d98d68edf4eae\",\r\n  \"weiDecimals\" => 8\r\n}\r\n\r\nHyperliquid.Cache.get_token_by_address(\"0xbaf265ef389da684513d98d68edf4eae\")\r\n%{\r\n  \"evmContract\" => nil,\r\n  \"fullName\" => nil,\r\n  \"index\" => 2,\r\n  \"isCanonical\" => false,\r\n  \"name\" => \"HFUN\",\r\n  \"szDecimals\" => 2,\r\n  \"tokenId\" => \"0xbaf265ef389da684513d98d68edf4eae\",\r\n  \"weiDecimals\" => 8\r\n}\r\n\r\nHyperliquid.Cache.get_token_key(\"PURR\")\r\n\"PURR:0xc1fb593aeffbeb02f85e0308e9956a90\"\r\n\r\nHyperliquid.Cache.get_token_by_name(\"PURR\") |> Cache.get_token_key()\r\n\"PURR:0xc1fb593aeffbeb02f85e0308e9956a90\"\r\n\r\nHyperliquid.Cache.get(:tokens)\r\n[\r\n  %{\r\n    \"evmContract\" => nil,\r\n    \"fullName\" => nil,\r\n    \"index\" => 0,\r\n    \"isCanonical\" => true,\r\n    \"name\" => \"USDC\",\r\n    \"szDecimals\" => 8,\r\n    \"tokenId\" => \"0x6d1e7cde53ba9467b783cb7c530ce054\",\r\n    \"weiDecimals\" => 8\r\n  },\r\n  ...\r\n]\r\n```\r\nOne great place to look for more insight on how to utilize the cache, is the Orders module.","ref":"readme.html#cache"},{"type":"extras","title":"License - Overview","doc":"This project is licensed under the MIT License.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}